<?php

namespace App\Presenters;

use Nette,
	App\Model;
use \Mesour\DataGrid\Grid,
	\Mesour\DataGrid\BasicGrid,
	\Mesour\DataGrid\NetteDbDataSource,
	\Mesour\DataGrid\Components\Link;
use  Nette\Application\UI;
use NasExt;


/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

/**
 * Description of Aktivity
 *
 * @author Erika
 */
class AktivityPresenter extends UI\Presenter{
    /**
     *
     * @inject 
     * @var \App\Model\MujModel
     */
    public $muj_model;
    
    public function createComponentAktivityGrid($name){        
        $selection = $this->muj_model->getTable('aktivity')
                ->select('aktivity.id, typ, popis, firmy_id, firmy.nazev');       
        $table_id = 'id'; 
        $source = new NetteDbDataSource($selection);
        $source->setPrimaryKey($table_id);       
        $grid = new Grid($this, $name);
        $grid->setDataSource($source);
        $grid->setEmptyText('Tato tabulka je prázdná');   
        $pager_limit = 8;     //nastaveni pageru    
        $grid->enablePager($pager_limit);            
        $grid->enableFilter($this['aktivityFiltr']); //nastaveni komponenty aktivityFiltr
        $filtrovana = $grid->getFilterValues();//filtr
        if (empty($filtrovana) === FALSE) {            
           if(isset($filtrovana['nazev'])&& !empty($filtrovana['nazev'])){
                $source->where('Firmy.nazev LIKE?', '%'.$filtrovana['nazev'].'%');          
            }                     
            if(isset($filtrovana['typ'])&& !empty($filtrovana['typ'])){
                $source->where('typ LIKE?', '%'.$filtrovana['typ'].'%');            
            }            
        }
        
        //editace
        $grid->enableEditableCells();
        $grid->onEditCell[]= $this->editColumn;
              
        //nastaveni gridu
        $grid->addText('nazev','Firma')   
             ->setEditable(FALSE);
        $grid->addText('typ','Typ aktivity');
        $grid->addText('popis','Popis aktivity');        
        $container = $grid->addContainer('akce', 'Akce')
                   ->setOrdering(FALSE);
        $action = $container->addActions('Akce');
        $action->addButton()
            ->setType('btn-danger')
            ->setIcon('glyphicon-trash')
            ->setConfirm('Opravdu chceš smazat vybranou aktivitu?')
            ->addAttribute('href', new Link(array(
             Link::HREF => 'deleteAktivita!',
             Link::PARAMS => array( 
                 'id'=>'{'. 'id'. '}' 
             )
         )));
       return $grid;        
    }
    
    public function createComponentAktivityFiltr() {
	$form = new UI\Form; 
        $form->addText('typ','Typ')->setAttribute('placeholder','Typ');
        $form->addText('nazev','Firma')->setAttribute('placeholder','Firma');		
        $form->addSubmit('filter','Filter');
        $form->addSubmit('reset','Reset'); 	
        return $form;
    }
    
    public function handleDeleteAktivita($id){
        $this->muj_model->getTable('aktivity')
                ->where('id = ?' , $id)->delete();
        $this->flashMessage("Informace o aktivitě byly smazány.", 'success');
        $this->redirect('this');
        
    }
    
             
  public function editColumn($line_id, $column_name, $new_value, $old_value) {
    $this->muj_model->getTable('aktivity')->where('id = ?', $line_id)
        ->update(array($column_name=> $new_value));
    }
        
    protected function createComponentEditAktivityForm(){
        $form = new Nette\Application\UI\Form;
        $firma = $this->muj_model->findAll()->fetchPairs('id', 'nazev');
        $form->addText('typ', 'Typ:');
        $form->addSelect('firmy_id', 'Firma:', $firma)
             ->setPrompt('-vyber firmu-')
             ->setRequired('Vyber firmu!');
        $form->addTextArea('popis', 'Komentář:')->setAttribute('cols', 50)
               ->setAttribute('rows', 4);
        $form->addSubmit('send', 'Uložit')->setAttribute('class', 'btn submit');
        $form->onSuccess[] = array($this, 'editAktivitaFormSucceeded'); 
        $form->addSubmit('cancel', 'Cancel')->setAttribute('class', 'btn cancel')
            ->setValidationScope(FALSE)
            ->onClick[] = array($this, 'cancelAktivita');
        return $form;
    }

    public function cancelAktivita(){
        $this->redirect('Aktivity:default');
    }

    public function editAktivitaFormSucceeded($form, $values){
        $this->muj_model->getTable('aktivity')->insert($values);
        $this->flashMessage("Aktivita byla vložena.", 'success');
        $this->redirect('Aktivity:default');
    }
}

    

